cosmpy.protos.cosmos.upgrade package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cosmpy.protos.cosmos.upgrade.v1beta1

Module contents
---------------

.. automodule:: cosmpy.protos.cosmos.upgrade
   :members:
   :undoc-members:
   :show-inheritance:
